==> beans-ddi-lifecycle-1.0.0-20130315.185903-7-sources.jar: org/openmetadata/beans/ddi/lifecycle/physicaldataproduct/impl/PhysicalLocationBeanImpl.java <==
package org.openmetadata.beans.ddi.lifecycle.physicaldataproduct.impl;

import org.openmetadata.beans.ddi.lifecycle.factory.DdiBeanFactory;
import org.openmetadata.beans.ddi.lifecycle.physicaldataproduct.PhysicalLocationBean;
import org.openmetadata.beans.ddi.lifecycle.reusable.impl.CodeValueBeanImpl;
import org.openmetadata.beans.ddi.lifecycle.reusable.impl.DdiBeanImpl;
import org.openmetadata.beans.ddi.lifecycle.utility.CompareUtil;
import org.apache.commons.lang3.StringUtils;
import org.openmetadata.beans.impl.MutableBeanInitializer;
import org.openmetadata.beans.notification.ChangeListener;

public class PhysicalLocationBeanImpl extends DdiBeanImpl implements
		PhysicalLocationBean {

	CodeValueBeanImpl storageFormat;
	String delimiter;
	Integer startPost;
	Integer arrayPost;
	Integer endPost;
	Integer width;
	Integer decimalPost;
	String decimalSeparator;
	String digitGroupSeparator;
	String languageOfData;
	String localeOfData;

	public PhysicalLocationBeanImpl(MutableBeanInitializer beanInitializer, DdiBeanFactory factory,
			ChangeListener listener) {
		super(beanInitializer, factory, listener);

		storageFormat = new CodeValueBeanImpl(factory, listener);
		delimiter = null;
		startPost = null;
		arrayPost = null;
		endPost = null;
		width = null;
		decimalSeparator = null;
		digitGroupSeparator = null;
		languageOfData = null;
		localeOfData = null;
	}

	@Override
	public CodeValueBeanImpl getStorageFormat() {
		if (storageFormat == null) {
			storageFormat = new CodeValueBeanImpl(this.getBeanFactory(), this);
		}
		return storageFormat;
	}

	@Override
	public boolean isSetDelimiter() {
		return this.delimiter != null;
	}

	@Override
	public void setDelimiter(String value) {
		if (CompareUtil.areDifferentValues(this.delimiter, value)) {
			this.delimiter = value;
			this.ddiBeanChanged();
		}
	}

	@Override
	public String getDelimiter() {
		if (this.delimiter != null) {
			return this.delimiter;
		} else {
			return "";
		}
	}

	@Override
	public boolean isSetStartPositon() {
		return this.startPost != null;
	}

	@Override
	public void setStartPositon(int value) {
		if (CompareUtil.areDifferentValues(this.startPost, value)) {
			this.startPost = value;
			this.ddiBeanChanged();
		}
	}

	@Override
	public int getStartPositon() {
		if (this.startPost != null) {
			return this.startPost;
		} else {
			return 0;
		}
	}

	@Override
	public boolean isSetArrayPosition() {
		return this.arrayPost != null;
	}

	@Override
	public void setArrayPosition(int value) {
		if (CompareUtil.areDifferentValues(this.arrayPost, value)) {
			this.arrayPost = value;
			this.ddiBeanChanged();
		}
	}

	@Override
	public int getArrayPosition() {
		if (this.arrayPost != null) {
			return this.arrayPost;
		} else {
			return 0;
		}
	}

	@Override
	public boolean isSetEndPosition() {
		return this.endPost != null;
	}

	@Override
	public void setEndPosition(int value) {
		if (CompareUtil.areDifferentValues(endPost, value)) {
			this.endPost = value;
			this.ddiBeanChanged();
		}
	}

	@Override
	public int getEndPosition() {
		if (this.endPost != null) {
			return this.endPost;
		} else {
			return 0;
		}
	}

	@Override
	public boolean isSetWidth() {
		return this.width != null;
	}

	@Override
	public void setWidth(int value) {
		if (CompareUtil.areDifferentValues(this.width, value)) {
			this.width = value;
			this.ddiBeanChanged();
		}
	}

	@Override
	public int getWidth() {
		if (this.width != null) {
			return this.width;
		} else {
			return 0;
		}
	}

	@Override
	public boolean isSetDecimalPositions() {
		return this.decimalPost != null;
	}

	@Override
	public void setDecimalPositions(int value) {
		if (CompareUtil.areDifferentValues(this.decimalPost, value)) {
			this.decimalPost = value;
			this.ddiBeanChanged();
		}
	}

	@Override
	public int getDecimalPositions() {
		if (this.decimalPost != null) {
			return this.decimalPost;
		} else {
			return 0;
		}
	}

	@Override
	public boolean isSetDecimalSeparator() {
		return this.decimalSeparator != null;
	}

	@Override
	public void setDecimalSeparator(char value) {
		if (CompareUtil.areDifferentValues(this.decimalSeparator, value + "")) {
			this.decimalSeparator = value + "";
			this.ddiBeanChanged();
		}
	}

	@Override
	public char getDecimalSeparator() {
		if (this.decimalSeparator != null
				&& this.decimalSeparator.isEmpty() == false) {
			return this.decimalSeparator.charAt(0);
		} else {
			return 0;
		}
	}

	@Override
	public boolean isSetDigitGroupSeparator() {
		return this.digitGroupSeparator != null;
	}

	@Override
	public void setDigitGroupSeparator(char value) {
		if (CompareUtil
				.areDifferentValues(this.digitGroupSeparator, value + "")) {
			this.digitGroupSeparator = value + "";
			this.ddiBeanChanged();
		}
	}

	@Override
	public char getDigitGroupSeparator() {
		if (this.digitGroupSeparator != null
				&& this.digitGroupSeparator.isEmpty() == false) {
			return this.digitGroupSeparator.charAt(0);
		} else {
			return 0;
		}
	}

	@Override
	public boolean isSetLanguageOfData() {
		return this.languageOfData != null;
	}

	@Override
	public void setLanguageOfData(String value) {
		if (CompareUtil.areDifferentValues(this.languageOfData, value)) {
			this.languageOfData = value;
			this.ddiBeanChanged();
		}
	}

	@Override
	public String getLanguageOfData() {
		if (this.languageOfData != null) {
			return this.languageOfData;
		} else {
			return "";
		}
	}

	@Override
	public boolean isSetLocaleOfData() {
		return this.localeOfData != null;
	}

	@Override
	public void setLocaleOfData(String value) {
		this.localeOfData = value;
		this.ddiBeanChanged();
	}

	@Override
	public String getLocaleOfData() {
		return StringUtils.defaultString(localeOfData);
	}

}

==> beans-ddi-lifecycle-1.0.0-20130708.211540-17-sources.jar: org/openmetadata/beans/ddi/lifecycle/physicaldataproduct/impl/PhysicalLocationBeanImpl.java <==
package org.openmetadata.beans.ddi.lifecycle.physicaldataproduct.impl;

import org.openmetadata.beans.ddi.lifecycle.factory.DdiBeanFactory;
import org.openmetadata.beans.ddi.lifecycle.impl.DdiBeanImpl;
import org.openmetadata.beans.ddi.lifecycle.physicaldataproduct.PhysicalLocationBean;
import org.openmetadata.beans.ddi.lifecycle.reusable.impl.CodeValueBeanImpl;
import org.openmetadata.beans.ddi.lifecycle.utility.CompareUtil;
import org.apache.commons.lang3.StringUtils;
import org.openmetadata.beans.impl.MutableBeanInitializer;
import org.openmetadata.beans.notification.ChangeListener;

public class PhysicalLocationBeanImpl extends DdiBeanImpl implements
		PhysicalLocationBean {

	CodeValueBeanImpl storageFormat;
	String delimiter;
	Integer startPost;
	Integer arrayPost;
	Integer endPost;
	Integer width;
	Integer decimalPost;
	String decimalSeparator;
	String digitGroupSeparator;
	String languageOfData;
	String localeOfData;

	public PhysicalLocationBeanImpl(MutableBeanInitializer beanInitializer, DdiBeanFactory factory,
			ChangeListener listener) {
		super(beanInitializer, factory, listener);

		storageFormat = new CodeValueBeanImpl(factory, listener);
		delimiter = null;
		startPost = null;
		arrayPost = null;
		endPost = null;
		width = null;
		decimalSeparator = null;
		digitGroupSeparator = null;
		languageOfData = null;
		localeOfData = null;
	}

	@Override
	public CodeValueBeanImpl getStorageFormat() {
		if (storageFormat == null) {
			storageFormat = new CodeValueBeanImpl(this.getBeanFactory(), this);
		}
		return storageFormat;
	}

	@Override
	public boolean isSetDelimiter() {
		return this.delimiter != null;
	}

	@Override
	public void setDelimiter(String value) {
		if (CompareUtil.areDifferentValues(this.delimiter, value)) {
			this.delimiter = value;
			this.ddiBeanChanged();
		}
	}

	@Override
	public String getDelimiter() {
		if (this.delimiter != null) {
			return this.delimiter;
		} else {
			return "";
		}
	}

	@Override
	public boolean isSetStartPositon() {
		return this.startPost != null;
	}

	@Override
	public void setStartPositon(int value) {
		if (CompareUtil.areDifferentValues(this.startPost, value)) {
			this.startPost = value;
			this.ddiBeanChanged();
		}
	}

	@Override
	public int getStartPositon() {
		if (this.startPost != null) {
			return this.startPost;
		} else {
			return 0;
		}
	}

	@Override
	public boolean isSetArrayPosition() {
		return this.arrayPost != null;
	}

	@Override
	public void setArrayPosition(int value) {
		if (CompareUtil.areDifferentValues(this.arrayPost, value)) {
			this.arrayPost = value;
			this.ddiBeanChanged();
		}
	}

	@Override
	public int getArrayPosition() {
		if (this.arrayPost != null) {
			return this.arrayPost;
		} else {
			return 0;
		}
	}

	@Override
	public boolean isSetEndPosition() {
		return this.endPost != null;
	}

	@Override
	public void setEndPosition(int value) {
		if (CompareUtil.areDifferentValues(endPost, value)) {
			this.endPost = value;
			this.ddiBeanChanged();
		}
	}

	@Override
	public int getEndPosition() {
		if (this.endPost != null) {
			return this.endPost;
		} else {
			return 0;
		}
	}

	@Override
	public boolean isSetWidth() {
		return this.width != null;
	}

	@Override
	public void setWidth(int value) {
		if (CompareUtil.areDifferentValues(this.width, value)) {
			this.width = value;
			this.ddiBeanChanged();
		}
	}

	@Override
	public int getWidth() {
		if (this.width != null) {
			return this.width;
		} else {
			return 0;
		}
	}

	@Override
	public boolean isSetDecimalPositions() {
		return this.decimalPost != null;
	}

	@Override
	public void setDecimalPositions(int value) {
		if (CompareUtil.areDifferentValues(this.decimalPost, value)) {
			this.decimalPost = value;
			this.ddiBeanChanged();
		}
	}

	@Override
	public int getDecimalPositions() {
		if (this.decimalPost != null) {
			return this.decimalPost;
		} else {
			return 0;
		}
	}

	@Override
	public boolean isSetDecimalSeparator() {
		return this.decimalSeparator != null;
	}

	@Override
	public void setDecimalSeparator(char value) {
		if (CompareUtil.areDifferentValues(this.decimalSeparator, value + "")) {
			this.decimalSeparator = value + "";
			this.ddiBeanChanged();
		}
	}

	@Override
	public char getDecimalSeparator() {
		if (this.decimalSeparator != null
				&& this.decimalSeparator.isEmpty() == false) {
			return this.decimalSeparator.charAt(0);
		} else {
			return 0;
		}
	}

	@Override
	public boolean isSetDigitGroupSeparator() {
		return this.digitGroupSeparator != null;
	}

	@Override
	public void setDigitGroupSeparator(char value) {
		if (CompareUtil
				.areDifferentValues(this.digitGroupSeparator, value + "")) {
			this.digitGroupSeparator = value + "";
			this.ddiBeanChanged();
		}
	}

	@Override
	public char getDigitGroupSeparator() {
		if (this.digitGroupSeparator != null
				&& this.digitGroupSeparator.isEmpty() == false) {
			return this.digitGroupSeparator.charAt(0);
		} else {
			return 0;
		}
	}

	@Override
	public boolean isSetLanguageOfData() {
		return this.languageOfData != null;
	}

	@Override
	public void setLanguageOfData(String value) {
		if (CompareUtil.areDifferentValues(this.languageOfData, value)) {
			this.languageOfData = value;
			this.ddiBeanChanged();
		}
	}

	@Override
	public String getLanguageOfData() {
		if (this.languageOfData != null) {
			return this.languageOfData;
		} else {
			return "";
		}
	}

	@Override
	public boolean isSetLocaleOfData() {
		return this.localeOfData != null;
	}

	@Override
	public void setLocaleOfData(String value) {
		this.localeOfData = value;
		this.ddiBeanChanged();
	}

	@Override
	public String getLocaleOfData() {
		return StringUtils.defaultString(localeOfData);
	}

}
